# Copyright 2021-2024 IQRF Tech s.r.o.
# Copyright 2021-2024 MICRORISC s.r.o.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

set(iqrf-header-parser_VERSION 1.0.0)
set(iqrf-header-parser_VERSION_MAJOR 1)
set(iqrf-header-parser_VERSION_MINOR 0)
set(iqrf-header-parser_VERSION_PATCH 0)


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was iqrf-header-parser-config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/arm-linux-gnueabihf/cmake/iqrf-header-parser" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

set(iqrf-header-parser_SHARED ON)
set(iqrf-header-parser_STATIC ON)

check_required_components(iqrf-header-parser)

if (NOT TARGET iqrf-header-parser AND NOT TARGET iqrf-header-parser_static)
	include(${CMAKE_CURRENT_LIST_DIR}/iqrf-header-parser-targets.cmake)
	set_and_check(iqrf-header-parser_INCLUDE_DIR "${PACKAGE_PREFIX_DIR}/include" CACHE PATH "Path to iqrf-header-parser includes")

	if (iqrf-header-parser_USE_STATIC AND NOT iqrf-header-parser_STATIC)
		message(FATAL_ERROR "Static library of iqrf-header-parser is not available")
	endif()

	if (NOT iqrf-header-parser_USE_STATIC AND NOT iqrf-header-parser_SHARED)
		message(FATAL_ERROR "Shared library of iqrf-header-parser is not available")
	endif()

	set(iqrf-header-parser_LIBRARIES "iqrf-header-parser")

	if (NOT iqrf-header-parser_FIND_QUIETLY)
		message(STATUS "Found iqrf-header-parser v${iqrf-header-parser_VERSION} includes: ${iqrf-header-parser_INCLUDE_DIR} and libraries: ${iqrf-header-parser_LIBRARIES}")
	endif()
endif()
